from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="PinRemovedEvent")


@_attrs_define
class PinRemovedEvent:
    """ピン削除イベント

    Attributes:
        user_id (str): 変更者UUID
        message_id (str): メッセージUUID
    """

    user_id: str
    message_id: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id

        message_id = self.message_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "userId": user_id,
                "messageId": message_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("userId")

        message_id = d.pop("messageId")

        pin_removed_event = cls(
            user_id=user_id,
            message_id=message_id,
        )

        pin_removed_event.additional_properties = d
        return pin_removed_event

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="PostWebhookRequest")


@_attrs_define
class PostWebhookRequest:
    """Webhook作成リクエスト

    Attributes:
        name (str): Webhookユーザーの表示名
        description (str): 説明
        channel_id (str): デフォルトの投稿先チャンネルUUID
        secret (str): Webhookシークレット
    """

    name: str
    description: str
    channel_id: str
    secret: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        description = self.description

        channel_id = self.channel_id

        secret = self.secret

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "description": description,
                "channelId": channel_id,
                "secret": secret,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        description = d.pop("description")

        channel_id = d.pop("channelId")

        secret = d.pop("secret")

        post_webhook_request = cls(
            name=name,
            description=description,
            channel_id=channel_id,
            secret=secret,
        )

        post_webhook_request.additional_properties = d
        return post_webhook_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
